@@ -4,11 +4,9 @@ use strict;
 use warnings;
 
 use Carp;
-use Exporter;
+use Exporter qw{ import };
 
-our @ISA = qw{ Exporter };
-
-our $VERSION = '0.179_002';
+our $VERSION = '0.095';
 
 our @EXPORT_OK = qw{ __any };
 
@@ -144,9 +142,7 @@ modules are needed it returns nothing.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack>,
-L<https://github.com/trwyant/perl-Astro-SpaceTrack/issues/>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -154,11 +150,11 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2026 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GPL>.
+of the licenses in the directory LICENSES.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
